==> jacobi_3.0.0.tar.gz: jacobi/README.md <==
# jacobi

<!-- badges: start -->
[![R-CMD-check](https://github.com/stla/jacobi/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/stla/jacobi/actions/workflows/R-CMD-check.yaml)
<!-- badges: end -->

Jacobi theta functions and related functions.

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/Dedekind.png)

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/Eisenstein4.png)

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/Eisenstein6.png)

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/sigma.png)

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/zeta.png)

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/wpprime.png)

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/Costa_full.gif)

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/Costa2.gif)

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/SigmaTorus.gif)

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/jellip_cn_1-16.png)

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/jellip_cn_circle_mobius.gif)

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/ball_cn.gif)

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/cm.png)

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/sl.png)

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/wp_Sobel.gif)

### Blog posts

- [Beautiful complex functions](https://laustep.github.io/stlahblog/posts/beautifulComplexFunctions.html)

- [On a Möbius transformation](https://laustep.github.io/stlahblog/posts/OnAMobiusTransformation.html)

==> jacobi_3.1.0.tar.gz: jacobi/README.md <==
# jacobi

<!-- badges: start -->
[![R-CMD-check](https://github.com/stla/jacobi/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/stla/jacobi/actions/workflows/R-CMD-check.yaml)
<!-- badges: end -->

Jacobi theta functions and related functions.

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/Dedekind.png)

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/Eisenstein4.png)

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/Eisenstein6.png)

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/sigma.png)

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/zeta.png)

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/wpprime.png)

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/Costa_full.gif)

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/Costa2.gif)

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/SigmaTorus.gif)

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/jellip_cn_1-16.png)

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/jellip_cn_circle_mobius.gif)

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/ball_cn.gif)

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/cm.png)

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/sl.png)

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/wp_Sobel.gif)

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/RogersRamanujanAlternating_pow5.png)

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/RogersRamanujanMobius.gif)

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/wpprime_equianharmonic.png)

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/lambda_Cayley.gif)

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/lambdaOnSquare.gif)

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/kleinOnSquare.gif)

![](https://raw.githubusercontent.com/stla/jacobi/main/inst/images/etaDedekindOnCircle.png)


### Blog posts

- [Beautiful complex functions](https://laustep.github.io/stlahblog/posts/beautifulComplexFunctions.html)

- [On a Möbius transformation](https://laustep.github.io/stlahblog/posts/OnAMobiusTransformation.html)

- [The pretty Klein j-invariant function](https://laustep.github.io/stlahblog/posts/KleinJinvariant.html)
